Package: ottr
Title: An R Autograding Extension for Otter-Grader
Version: 1.5.3
Authors@R: c(
    person(given = "Christopher",
           family = "Pyles",
           email = "cpyles@berkeley.edu",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-8520-7593")),
    person(given = "UC Berkeley Data Science Education Program",
           role = c("cph")))
Maintainer: Christopher Pyles <cpyles@berkeley.edu>
Description: 
    An R autograding extension for Otter-Grader (<https://otter-grader.readthedocs.io>). It supports 
    grading R scripts, R Markdown documents, and R Jupyter Notebooks.
License: BSD_3_clause + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 4.0.0)
Imports: jsonlite, testthat, tools, R6, zip, methods
Suggests: IRdisplay, mockery, rmarkdown, stringr, withr, IRkernel
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-10-12 00:06:34 UTC; chrispyles
Author: Christopher Pyles [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8520-7593>),
  UC Berkeley Data Science Education Program [cph]
Repository: CRAN
Date/Publication: 2025-10-12 02:20:02 UTC
Built: R 4.6.0; ; 2026-04-28 19:58:04 UTC; unix
