# Ottr

[![Run tests](https://github.com/ucbds-infra/ottr/actions/workflows/run-tests.yml/badge.svg)](https://github.com/ucbds-infra/ottr/actions/workflows/run-tests.yml)
[![codecov](https://codecov.io/gh/ucbds-infra/ottr/branch/master/graph/badge.svg?token=7UL6L4JYX1)](https://app.codecov.io/gh/ucbds-infra/ottr)

Ottr is a client-side R autograding package that is designed to be mixed into 
[Otter-Grader](https://github.com/ucbds-infra/otter-grader) to extend it to R Jupyter Notebooks, R 
scripts, and Rmd and Quarto documents.

For more details about ottr and its usage, see the [Otter-Grader documentation](https://otter-grader.rtfd.io).
