% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_collector.R
\name{initialize_collector}
\alias{initialize_collector}
\title{Create a new global \link{CheckCollector}}
\usage{
initialize_collector()
}
\description{
Create a new global \link{CheckCollector}
}
