% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_collector.R
\name{get_collector}
\alias{get_collector}
\title{Retrieve the global \link{CheckCollector}}
\usage{
get_collector()
}
\description{
Retrieve the global \link{CheckCollector}
}
